Type

Struct Type 

#[non_exhaustive]
pub struct Type { pub kind: TypeKind, pub size: Option<usize>, }
🔬This is a nightly-only experimental API. (type_info #146922)
Compile-time type information.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
kind: TypeKind
🔬This is a nightly-only experimental API. (type_info #146922)

Per-type information

size: Option<usize>
🔬This is a nightly-only experimental API. (type_info #146922)

Size of the type. None if it is unsized

Implementations

Source

impl Type

pub const fn of<T>() -> Type
where T: ?Sized,

🔬This is a nightly-only experimental API. (type_info #146922)

Returns the type information of the generic type parameter.

Note: Unlike TypeIds obtained via TypeId::of, the Type struct and its fields contain TypeIds that are not necessarily derived from types that outlive 'static. This means that using the TypeIds (transitively) obtained from this function will be able to break invariants that other TypeId consuming crates may have assumed to hold.